OC.L10N.register(
    "core",
    {
    "Please select a file." : "A roghnaigh comhad le do thoil.",
    "File is too big" : "Tá an comhad ró-mhór",
    "The selected file is not an image." : "Ní íomhá é an comhad roghnaithe.",
    "The selected file cannot be read." : "Ní féidir an comhad roghnaithe a léamh.",
    "The file was uploaded" : "Uaslódáladh an comhad",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Sáraíonn an comhad uaslódáilte an treoir upload_max_filesize i php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Sáraíonn an comhad uaslódáilte an treoir MAX_FILE_SIZE a sonraíodh san fhoirm HTML",
    "The file was only partially uploaded" : "Níor uaslódáladh an comhad ach go páirteach",
    "No file was uploaded" : "Níor uaslódáladh aon chomhad",
    "Missing a temporary folder" : "Fillteán sealadach ar iarraidh",
    "Could not write file to disk" : "Níorbh fhéidir an comhad a scríobh ar an diosca",
    "A PHP extension stopped the file upload" : "Chuir síneadh PHP stop le huaslódáil an chomhaid",
    "Invalid file provided" : "Comhad neamhbhailí curtha ar fáil",
    "No image or file provided" : "Níor cuireadh íomhá nó comhad ar bith ar fáil",
    "Unknown filetype" : "Cineál comhaid anaithnid",
    "An error occurred. Please contact your admin." : "Tharla earráid. Déan teagmháil le do riarthóir le do thoil.",
    "Invalid image" : "Íomhá neamhbhailí",
    "State token does not match" : "Ní hionann an comhartha stáit",
    "Invalid app password" : "Pasfhocal feidhmchláir neamhbhailí",
    "Could not complete login" : "Níorbh fhéidir logáil isteach a chríochnú",
    "State token missing" : "Comhartha stáit in easnamh",
    "Your login token is invalid or has expired" : "Tá do chomhartha logáil isteach neamhbhailí nó imithe in éag",
    "Please use original client" : "Bain úsáid as an gcliant bunaidh le do thoil",
    "This community release of Nextcloud is unsupported and push notifications are limited." : "Ní thacaítear leis an scaoileadh pobail seo de Nextcloud agus tá teorainn le fógraí brú.",
    "Login" : "Logáil isteach",
    "Unsupported email length (>255)" : "Fad ríomhphoist nach dtacaítear leis (>255)",
    "Password reset is disabled" : "Tá athshocrú pasfhocail díchumasaithe",
    "Could not reset password because the token is expired" : "Níorbh fhéidir an pasfhocal a athshocrú toisc go bhfuil an comhartha imithe in éag",
    "Could not reset password because the token is invalid" : "Níorbh fhéidir an pasfhocal a athshocrú toisc go bhfuil an comhartha neamhbhailí",
    "Password is too long. Maximum allowed length is 469 characters." : "Tá pasfhocal ró-fhada. Is é 469 carachtar an fad uasta a cheadaítear.",
    "%s password reset" : "%sathshocrú pasfhocal",
    "Password reset" : "Athshocrú pasfhocal",
    "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Cliceáil ar an gcnaipe seo a leanas chun do phasfhocal a athshocrú. Mura bhfuil athshocrú an phasfhocail iarrtha agat, déan neamhaird den ríomhphost seo.",
    "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Cliceáil ar an nasc seo a leanas chun do phasfhocal a athshocrú. Mura bhfuil athshocrú an phasfhocail iarrtha agat, déan neamhaird den ríomhphost seo.",
    "Reset your password" : "Athshocraigh do phasfhocal",
    "The given provider is not available" : "Níl an soláthraí tugtha ar fáil",
    "Task not found" : "Níor aimsíodh an tasc",
    "Internal error" : "Earráid inmheánach",
    "Not found" : "Ní bhfuarthas",
    "Node is locked" : "Tá an nód faoi ghlas",
    "Bad request" : "Drochiarratas",
    "Input text is too long" : "Tá an téacs ionchuir rófhada",
    "Requested task type does not exist" : "Níl an cineál taisc iarrtha ann",
    "Necessary language model provider is not available" : "Níl soláthraí múnla teanga riachtanach ar fáil",
    "No text to image provider is available" : "Níl aon soláthraí téacs go híomhá ar fáil",
    "Image not found" : "Ní bhfuarthas an íomhá",
    "No translation provider available" : "Níl aon soláthraí aistriúcháin ar fáil",
    "Could not detect language" : "Níorbh fhéidir teanga a bhrath",
    "Unable to translate" : "Ní féidir aistriú",
    "No valid filters provided" : "Níor soláthraíodh aon scagairí bailí",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair step:" : "Céim deisiúcháin:",
    "Repair info:" : "Eolas deisiúcháin:",
    "Repair warning:" : "Rabhadh deisiúcháin:",
    "Repair error:" : "Earráid deisiúcháin:",
    "Nextcloud Server" : "Freastalaí Nextcloud",
    "Some of your link shares have been removed" : "Baineadh cuid de do chuid naisc",
    "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Mar gheall ar fhabht slándála bhí orainn roinnt de do naisc a roinnt. Féach ar an nasc le haghaidh tuilleadh eolais.",
    "The account limit of this instance is reached." : "Sroichtear teorainn chuntas na háise seo.",
    "Enter your subscription key in the support app in order to increase the account limit. This does also grant you all additional benefits that Nextcloud Enterprise offers and is highly recommended for the operation in companies." : "Cuir isteach d'eochair síntiúis san aip tacaíochta chun teorainn an chuntais a mhéadú. Tugann sé seo freisin na buntáistí breise go léir a thairgeann Nextcloud Enterprise agus moltar go mór é don oibríocht i gcuideachtaí.",
    "Learn more ↗" : "Tuilleadh eolais ↗",
    "Preparing update" : "Nuashonrú a ullmhú",
    "Please use the command line updater because updating via browser is disabled in your config.php." : "Bain úsáid as an nuashonróir líne ordaithe toisc go bhfuil nuashonrú trí bhrabhsálaí díchumasaithe i do config.php.",
    "Turned on maintenance mode" : "Cuireadh modh cothabhála ar siúl",
    "Turned off maintenance mode" : "Modh cothabhála múchta",
    "Maintenance mode is kept active" : "Coinnítear modh cothabhála gníomhach",
    "Updating database schema" : "Íoslódáil bunachar sonraí scéim cothrom le dáta",
    "Updated database" : "Bunachar sonraí nuashonraithe",
    "Update app \"%s\" from App Store" : "Nuashonraigh aip \"%s\" ón Siopa Aipeanna",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Ag seiceáil an féidir scéimre an bhunachair sonraí le haghaidh%sa nuashonrú (féadfaidh sé seo go leor ama a ghlacadh ag brath ar mhéid an bhunachair sonraí)",
    "Updated \"%1$s\" to %2$s" : "Nuashonraíodh \"%1$s\" go %2$s",
    "Set log level to debug" : "Socraigh leibhéal an loga chuig dífhabhtú",
    "Reset log level" : "Athshocraigh leibhéal an loga",
    "Starting code integrity check" : "Seiceáil sláine an chóid tosaithe",
    "Finished code integrity check" : "Críochnaithe seiceáil sláine cód",
    "%s (incompatible)" : "%s (neamh-chomhoiriúnach)",
    "The following apps have been disabled: %s" : "Díchumasaíodh na haipeanna seo a leanas:%s",
    "Already up to date" : "Cheana féin suas chun dáta",
    "Windows Command Script" : "Script Ordú Windows",
    "Electronic book document" : "Doiciméad leabhar leictreonach",
    "TrueType Font Collection" : "Bailiúchán Clónna TrueType",
    "Web Open Font Format" : "Formáid Cló Oscailte Gréasáin",
    "GPX geographic data" : "Sonraí geografacha GPX",
    "Gzip archive" : "Cartlann Gzip",
    "Adobe Illustrator document" : "Doiciméad Adobe Illustrator",
    "Java source code" : "Cód foinse Java",
    "JavaScript source code" : "Cód foinse JavaScript",
    "JSON document" : "Doiciméad JSON",
    "Microsoft Access database" : "Bunachar sonraí Microsoft Access",
    "Microsoft OneNote document" : "Doiciméad Microsoft OneNote",
    "Microsoft Word document" : "Doiciméad Microsoft Word",
    "Unknown" : "Anaithnid",
    "PDF document" : "Doiciméad PDF",
    "PostScript document" : "Doiciméad PostScript",
    "RSS summary" : "Achoimre RSS",
    "Android package" : "Pacáiste Android",
    "KML geographic data" : "Sonraí geografacha KML",
    "KML geographic compressed data" : "Sonraí comhbhrúite geografacha KML",
    "Lotus Word Pro document" : "Doiciméad Lotus Word Pro",
    "Excel spreadsheet" : "Scarbhileog Excel",
    "Excel add-in" : "Breiseán Excel",
    "Excel 2007 binary spreadsheet" : "Scarbhileog dhénártha Excel 2007",
    "Excel spreadsheet template" : "Teimpléad scarbhileog Excel",
    "Outlook Message" : "Teachtaireacht Outlook",
    "PowerPoint presentation" : "Cur i láthair PowerPoint",
    "PowerPoint add-in" : "Breiseán PowerPoint",
    "PowerPoint presentation template" : "Teimpléad cur i láthair PowerPoint",
    "Word document" : "Doiciméad Word",
    "ODF formula" : "Foirmle ODF",
    "ODG drawing" : "Líníocht ODG",
    "ODG drawing (Flat XML)" : "Líníocht ODG (XML Cothrom)",
    "ODG template" : "Teimpléad ODG",
    "ODP presentation" : "Cur i láthair ODP",
    "ODP presentation (Flat XML)" : "Cur i láthair ODP (XML Cothrom)",
    "ODP template" : "Teimpléad ODP",
    "ODS spreadsheet" : "Scarbhileog ODS",
    "ODS spreadsheet (Flat XML)" : "Scarbhileog ODS (XML Cothrom)",
    "ODS template" : "Teimpléad ODS",
    "ODT document" : "Doiciméad ODT",
    "ODT document (Flat XML)" : "Doiciméad ODT (XML Cothrom)",
    "ODT template" : "Teimpléad ODT",
    "PowerPoint 2007 presentation" : "Cur i láthair PowerPoint 2007",
    "PowerPoint 2007 show" : "Taispeántas PowerPoint 2007",
    "PowerPoint 2007 presentation template" : "Teimpléad cur i láthair PowerPoint 2007",
    "Excel 2007 spreadsheet" : "Scarbhileog Excel 2007",
    "Excel 2007 spreadsheet template" : "Teimpléad scarbhileog Excel 2007",
    "Word 2007 document" : "Doiciméad Word 2007",
    "Word 2007 document template" : "Teimpléad doiciméad Word 2007",
    "Microsoft Visio document" : "Doiciméad Microsoft Visio",
    "WordPerfect document" : "Doiciméad WordPerfect",
    "7-zip archive" : "Cartlann 7-zip",
    "Blender scene" : "Radharc cumascóra",
    "Bzip2 archive" : "Cartlann Bzip2",
    "Debian package" : "Pacáiste Debian",
    "FictionBook document" : "Doiciméad FictionBook",
    "Unknown font" : "Cló anaithnid",
    "Krita document" : "Doiciméad Krita",
    "Mobipocket e-book" : "Ríomhleabhar Mobipocket",
    "Windows Installer package" : "Pacáiste Suiteálaí Windows",
    "Perl script" : "Script Perl",
    "PHP script" : "Script PHP",
    "Tar archive" : "Cartlann Tar",
    "XML document" : "Doiciméad XML",
    "YAML document" : "Doiciméad YAML",
    "Zip archive" : "Cartlann zip",
    "Zstandard archive" : "Cartlann Zstandard",
    "AAC audio" : "Fuaim AAC",
    "FLAC audio" : "Fuaim FLAC",
    "MPEG-4 audio" : "Fuaim MPEG-4",
    "MP3 audio" : "Fuaim MP3",
    "Ogg audio" : "Fuaim Ogg",
    "RIFF/WAVe standard Audio" : "Fuaim chaighdeánach RIFF/WAVe",
    "WebM audio" : "Fuaim WebM",
    "MP3 ShoutCast playlist" : "Seinmliosta MP3 ShoutCast",
    "Windows BMP image" : "Íomhá BMP Windows",
    "Better Portable Graphics image" : "Íomhá Grafaicí Inaistrithe Níos Fearr",
    "EMF image" : "Íomhá EMF",
    "GIF image" : "Íomhá GIF",
    "HEIC image" : "Íomhá HEIC",
    "HEIF image" : "Íomhá HEIF",
    "JPEG-2000 JP2 image" : "Íomhá JPEG-2000 JP2",
    "JPEG image" : "Íomhá JPEG",
    "PNG image" : "Íomhá PNG",
    "SVG image" : "Íomhá SVG",
    "Truevision Targa image" : "Íomhá Truevision Targa",
    "TIFF image" : "Íomhá TIFF",
    "WebP image" : "Íomhá WebP",
    "Digital raw image" : "Íomhá amh digiteach",
    "Windows Icon" : "Deilbhín Windows",
    "Email message" : "Teachtaireacht ríomhphoist",
    "VCS/ICS calendar" : "Féilire VCS/ICS",
    "CSS stylesheet" : "Bileog stíle CSS",
    "CSV document" : "Doiciméad CSV",
    "HTML document" : "Doiciméad HTML",
    "Markdown document" : "Doiciméad marcála síos",
    "Org-mode file" : "Comhad mód eagraíochta",
    "Plain text document" : "Doiciméad téacs simplí",
    "Rich Text document" : "Doiciméad Téacs Saibhir",
    "Electronic business card" : "Cárta gnó leictreonach",
    "C++ source code" : "Cód foinse C++",
    "LDIF address book" : "Leabhar seoltaí LDIF",
    "NFO document" : "Doiciméad NFO",
    "PHP source" : "Foinse PHP",
    "Python script" : "Script Python",
    "ReStructuredText document" : "Doiciméad AthstruchtúrthaTéacs",
    "3GPP multimedia file" : "Comhad ilmheán 3GPP",
    "MPEG video" : "Físeán MPEG",
    "DV video" : "Físeán DV",
    "MPEG-2 transport stream" : "Sruth iompair MPEG-2",
    "MPEG-4 video" : "Físeán MPEG-4",
    "Ogg video" : "Físeán Ogg",
    "QuickTime video" : "Físeán QuickTime",
    "WebM video" : "Físeán WebM",
    "Flash video" : "Físeán Flash",
    "Matroska video" : "Físeán Matroska",
    "Windows Media video" : "Físeán Windows Media",
    "AVI video" : "Físeán AVI",
    "The update is in progress, leaving this page might interrupt the process in some environments." : "Tá an nuashonrú ar siúl, agus d'fhéadfadh go gcuirfí isteach ar an bpróiseas i dtimpeallachtaí áirithe dá bhfágfaí an leathanach seo.",
    "Update to {version}" : "Nuashonraigh go {version}",
    "An error occurred." : "Tharla earráid.",
    "Please reload the page." : "Athlódáil an leathanach le do thoil.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Níor éirigh leis an nuashonrú. Le haghaidh tuilleadh faisnéise <a href=\"{url}\">seiceáil ár bpost fóraim</a> a chlúdaíonn an tsaincheist seo.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Níor éirigh leis an nuashonrú.  Tuairiscigh an tsaincheist seo do <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">phobal Nextcloud </a> le do thoil.",
    "Continue to {productName}" : "Lean ar aghaidh chuig {productName}",
    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["D'éirigh leis an nuashonrú. Tú á atreorú chuig {productName} i gceann %n soicind.","The update was successful. Redirecting you to {productName} in %n seconds.","D'éirigh leis an nuashonrú. Tú á atreorú chuig {productName} i gceann %n soicind.","D'éirigh leis an nuashonrú. Tú á atreorú chuig {productName} i gceann %n soicind.","D'éirigh leis an nuashonrú. Tú á atreorú chuig {productName} i gceann %n soicind."],
    "Done" : "Déanta",
    "Applications menu" : "Roghchlár feidhmchlár",
    "Apps" : "Feidhmchláir",
    "More apps" : "Tuilleadh apps",
    "_{count} notification_::_{count} notifications_" : ["{count} fógra","{count} fógra","{count} fógra","{count} fógra","{count} fógra"],
    "No" : "Níl",
    "Yes" : "Tá",
    "App password" : "Pasfhocal aip",
    "Grant access" : "Deonaigh rochtain",
    "The remote URL must include the user." : "Ní mór an t-úsáideoir a chur san áireamh sa URL iargúlta.",
    "Invalid remote URL." : "URL cianda neamhbhailí.",
    "Failed to add the public link to your Nextcloud" : "Theip ar an nasc poiblí a chur le do Nextcloud",
    "Federated user" : "Úsáideoir cónaidhme",
    "user@your-nextcloud.org" : "user@your-nextcloud.org",
    "Create share" : "Cruthaigh sciar",
    "Direct link copied" : "Nasc díreach cóipeáilte",
    "Please copy the link manually:" : "Cóipeáil an nasc de láimh le do thoil:",
    "Custom date range" : "Raon dáta saincheaptha",
    "Pick start date" : "Roghnaigh dáta tosaithe",
    "Pick end date" : "Roghnaigh dáta deiridh",
    "Search in date range" : "Cuardaigh i raon dáta",
    "Search in current app" : "Cuardaigh san aip reatha",
    "Clear search" : "Glan cuardach",
    "Search everywhere" : "Cuardaigh i ngach áit",
    "Searching …" : "Ag cuardach …",
    "Start typing to search" : "Tosaigh ag clóscríobh chun cuardach a dhéanamh",
    "Minimum search length is {minSearchLength} characters" : "Is é {minSearchLength} carachtar an fad cuardaigh íosta",
    "No matching results" : "Gan torthaí meaitseála",
    "Today" : "Inniu",
    "Last 7 days" : "7 lá seo caite",
    "Last 30 days" : "30 lá anuas",
    "This year" : "An bhliain seo",
    "Last year" : "Anuraidh",
    "Between {startDate} and {endDate}" : "Idir {startDate} agus {endDate}",
    "Unified search" : "Cuardach aontaithe",
    "Search apps, files, tags, messages" : "Cuardaigh apps, comhaid, clibeanna, teachtaireachtaí",
    "Places" : "Áiteanna",
    "Date" : "Dáta",
    "Search people" : "Cuardaigh daoine",
    "People" : "Daoine",
    "Filter in current view" : "Scag san amharc reatha",
    "Search connected services" : "Cuardaigh seirbhísí nasctha",
    "Results" : "Torthaí",
    "Load more results" : "Íoslódáil níos mó torthaí",
    "Search in" : "Cuardaigh isteach",
    "Partial matches" : "Cluichí páirteacha",
    "Log in" : "Logáil isteach",
    "Logging in …" : "Ag logáil isteach …",
    "Log in to {productName}" : "Logáil isteach ar {productName}",
    "Wrong login or password." : "Logáil isteach mícheart nó pasfhocal.",
    "This account is disabled" : "Tá an cuntas seo díchumasaithe",
    "Too many incorrect login attempts. Please try again in 30 seconds." : "An iomarca iarrachtaí logála isteach míchearta. Déan iarracht arís i gceann 30 soicind.",
    "Account name or email" : "Ainm cuntais nó ríomhphost",
    "Account name" : "Ainm chuntais",
    "Server side authentication failed!" : "Theip ar fhíordheimhniú taobh an fhreastalaí!",
    "Please contact your administrator." : "Déan teagmháil le do riarthóir.",
    "Session error" : "Earráid seisiúin",
    "It appears your session token has expired, please refresh the page and try again." : "Is cosúil go bhfuil do chomhartha seisiúin imithe in éag, athnuaigh an leathanach agus bain triail eile as.",
    "An internal error occurred." : "Tharla earráid inmheánach.",
    "Please try again or contact your administrator." : "Bain triail eile as nó déan teagmháil le do riarthóir.",
    "Password" : "Pasfhocal",
    "Remember me" : "Cuimhnigh orm",
    "Log in with a device" : "Logáil isteach le gléas",
    "Login or email" : "Logáil isteach nó ríomhphost",
    "Your account is not setup for passwordless login." : "Níl do chuntas socraithe le haghaidh logáil isteach gan pasfhocal.",
    "Your connection is not secure" : "Níl do nasc slán",
    "Passwordless authentication is only available over a secure connection." : "Níl fíordheimhniú gan pasfhocal ar fáil ach thar nasc slán.",
    "Browser not supported" : "Ní thacaítear leis an mbrabhsálaí",
    "Passwordless authentication is not supported in your browser." : "Ní thacaítear le fíordheimhniú gan pasfhocal i do bhrabhsálaí.",
    "Reset password" : "Athshocraigh pasfhocal",
    "Back to login" : "Ar ais chuig logáil isteach",
    "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or Login, check your spam/junk folders or ask your local administration for help." : "Má tá an cuntas seo ann, tá teachtaireacht athshocraithe pasfhocail seolta chuig a sheoladh ríomhphoist. Mura bhfaigheann tú é, fíoraigh do sheoladh ríomhphoist agus/nó Logáil Isteach, seiceáil d’fhillteáin turscair/dramhphoist nó iarr cabhair ar do riarachán áitiúil.",
    "Couldn't send reset email. Please contact your administrator." : "Níorbh fhéidir ríomhphost athshocraithe a sheoladh. Déan teagmháil le do riarthóir le do thoil.",
    "Password cannot be changed. Please contact your administrator." : "Ní féidir pasfhocal a athrú. Déan teagmháil le do riarthóir.",
    "New password" : "Pasfhocal Nua",
    "Your files are encrypted. There will be no way to get your data back after your password is reset. If you are not sure what to do, please contact your administrator before you continue. Do you really want to continue?" : "Tá do chuid comhad criptithe. Ní bheidh aon bhealach chun do shonraí a fháil ar ais tar éis do phasfhocal a athshocrú. Mura bhfuil tú cinnte cad atá le déanamh, déan teagmháil le do riarthóir sula leanann tú ar aghaidh. Ar mhaith leat leanúint ar aghaidh i ndáiríre?",
    "I know what I'm doing" : "Tá a fhios agam cad atá á dhéanamh agam",
    "Resetting password" : "Pasfhocal a athshocrú",
    "Schedule work & meetings, synced with all your devices." : "Sceidealaigh obair & cruinnithe, sioncronaithe le do ghléasanna go léir.",
    "Keep your colleagues and friends in one place without leaking their private info." : "Coinnigh do chomhghleacaithe agus do chairde in aon áit amháin gan a gcuid faisnéise príobháideacha a sceitheadh.",
    "Simple email app nicely integrated with Files, Contacts and Calendar." : "Feidhmchlár ríomhphoist simplí atá comhtháite go deas le Comhaid, Teagmhálaithe agus Féilire.",
    "Chatting, video calls, screen sharing, online meetings and web conferencing – in your browser and with mobile apps." : "Comhrá, físghlaonna, comhroinnt scáileáin, cruinnithe ar líne agus comhdháil gréasáin – i do bhrabhsálaí agus le haipeanna móibíleacha.",
    "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Doiciméid chomhoibríocha, scarbhileoga agus cur i láthair, tógtha ar Collabora Online.",
    "Distraction free note taking app." : "Clár chun nótaí a tharraingt saor in aisce,.",
    "Recommended apps" : "Aipeanna molta",
    "Loading apps …" : "Ag lódáil aipeanna …",
    "Could not fetch list of apps from the App Store." : "Níorbh fhéidir liosta aipeanna a fháil ón App Store.",
    "App download or installation failed" : "Theip ar íoslódáil nó suiteáil an aip",
    "Cannot install this app because it is not compatible" : "Ní féidir an aip seo a shuiteáil toisc nach bhfuil sé comhoiriúnach",
    "Cannot install this app" : "Ní féidir an aip seo a shuiteáil",
    "Skip" : "Scipeáil",
    "Installing apps …" : "Ag suiteáil aipeanna …",
    "Install recommended apps" : "Suiteáil aipeanna molta",
    "Online" : "Ar líne",
    "Away" : "Amach",
    "Busy" : "Gnóthach",
    "Do not disturb" : "Ná cur as",
    "Mute all notifications" : "Balbhaigh gach fógra",
    "Invisible" : "Dofheicthe",
    "Appear offline" : "Le feiceáil as líne",
    "Avatar of {displayName}" : "Avatar de {displayName}",
    "Settings menu" : "Roghchlár socruithe",
    "Loading your contacts …" : "Ag lódáil do theagmhálaithe …",
    "Looking for {term} …" : "Ag lorg {term} …",
    "Search contacts" : "Cuardaigh teagmhálaithe",
    "Reset search" : "Athshocraigh cuardach",
    "Search contacts …" : "Cuardaigh teagmhálaithe …",
    "Could not load your contacts" : "Níorbh fhéidir do theagmhálaithe a lódáil",
    "No contacts found" : "Níor aimsíodh aon teagmhálaí",
    "Show all contacts" : "Taispeáin gach teagmháil",
    "Install the Contacts app" : "Suiteáil an app Teagmhálacha",
    "Search" : "Cuardach",
    "No results for {query}" : "Níl aon torthaí le haghaidh {query}",
    "Press Enter to start searching" : "Brúigh Enter chun cuardach a thosú",
    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Cuir isteach {minSearchLength} carachtar nó níos mó chun cuardach a dhéanamh le do thoil","Cuir isteach {minSearchLength} carachtair nó níos mó chun cuardach a dhéanamh le do thoil","Cuir isteach {minSearchLength} carachtair nó níos mó chun cuardach a dhéanamh le do thoil","Cuir isteach {minSearchLength} carachtair nó níos mó chun cuardach a dhéanamh le do thoil","Cuir isteach {minSearchLength} carachtair nó níos mó chun cuardach a dhéanamh le do thoil"],
    "An error occurred while searching for {type}" : "Tharla earráid agus {type} á chuardach",
    "Search starts once you start typing and results may be reached with the arrow keys" : "Tosaíonn an cuardach nuair a thosaíonn tú ag clóscríobh agus is féidir na torthaí a bhaint amach leis na heochracha saigheada",
    "Search for {name} only" : "Déan cuardach ar {name} amháin",
    "Loading more results …" : "Tuilleadh torthaí á lódáil …",
    "Forgot password?" : "Dearmad ar pasfhocal?",
    "Back to login form" : "Ar ais go dtí an fhoirm logáil isteach",
    "Back" : "Ar ais",
    "Login form is disabled." : "Tá an fhoirm logáil isteach díchumasaithe.",
    "The Nextcloud login form is disabled. Use another login option if available or contact your administration." : "Tá foirm logáil isteach Nextcloud díchumasaithe. Úsáid rogha logáil isteach eile má tá sé ar fáil nó déan teagmháil le do lucht riaracháin.",
    "Connect to your account" : "Ceangail le do chuntas",
    "Security warning" : "Rabhadh slándála",
    "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "Mura bhfuil tú ag iarraidh gléas nó aip nua a chur ar bun, tá duine éigin ag iarraidh bob a bhualadh ort rochtain a thabhairt dóibh ar do shonraí. Sa chás seo, ná téigh ar aghaidh agus ina ionad sin déan teagmháil le riarthóir do chórais.",
    "Alternative log in using app password" : "Logáil isteach malartach ag baint úsáide as pasfhocal app",
    "Account connected" : "Cuntas ceangailte",
    "Your client should now be connected!" : "Ba chóir go mbeadh do chliant ceangailte anois!",
    "You can close this window." : "Is féidir leat an fhuinneog seo a dhúnadh.",
    "Account access" : "Rochtain chuntais",
    "More actions" : "Tuilleadh gníomhartha",
    "User menu" : "Roghchlár úsáideora",
    "Your guest name: {user}" : "Ainm d'aoi: {user}",
    "You are currently not identified." : "Níl aitheantas tugtha duit faoi láthair.",
    "Set public name" : "Socraigh ainm poiblí",
    "Change public name" : "Athraigh ainm poiblí",
    "This share is password-protected" : "Tá an sciar seo cosanta ag pasfhocal",
    "The password is wrong or expired. Please try again or request a new one." : "Tá an pasfhocal mícheart nó imithe in éag. Bain triail eile as nó iarr ceann nua le do thoil. ",
    "Submit" : "Cuir isteach",
    "Please type in your email address to request a temporary password" : "Clóscríobh isteach do sheoladh ríomhphoist chun pasfhocal sealadach a iarraidh le do thoil",
    "Password sent!" : "Pasfhocal seolta!",
    "You are not authorized to request a password for this share" : "Níl tú údaraithe pasfhocal a iarraidh don sciar seo",
    "Email address" : "Seoladh ríomhphoist",
    "Request password" : "Iarr pasfhocal",
    "Password is too weak" : "Tá pasfhocal ró-lag",
    "Password is weak" : "Tá pasfhocal lag",
    "Password is average" : "Is pasfhocal meánach",
    "Password is strong" : "Tá pasfhocal láidir",
    "Password is very strong" : "Tá pasfhocal an-láidir",
    "Password is extremely strong" : "Tá pasfhocal thar a bheith láidir",
    "Unknown password strength" : "Neart phasfhocal anaithnid",
    "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Is dócha go bhfuil do eolaire sonraí agus comhaid inrochtana ón idirlíon toisc nach n-oibríonn an comhad <code>.htaccess</code>.",
    "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Chun eolas a fháil ar conas do fhreastalaí a chumrú i gceart, {linkStart}féach ar an doiciméadú{linkEnd}",
    "Autoconfig file detected" : "Braitheadh ​​comhad Autoconfig",
    "The setup form below is pre-filled with the values from the config file." : "Tá an fhoirm socraithe thíos réamhlíonta leis na luachanna ón gcomhad cumraíochta.",
    "Create administration account" : "Cruthaigh cuntas riaracháin",
    "Administration account name" : "Ainm an chuntais riaracháin",
    "Administration account password" : "Pasfhocal cuntas riaracháin",
    "Storage & database" : "Stóráil agus bunachar sonraí",
    "Data folder" : "Fillteán sonraí",
    "Database configuration" : "Cumraíocht bunachar sonraí",
    "Database type" : "Cineál bunachar sonraí",
    "Only {firstAndOnlyDatabase} is available." : "Níl ach {firstAndOnlyDatabase} ar fáil.",
    "Install and activate additional PHP modules to choose other database types." : "Suiteáil agus gníomhachtaigh modúil PHP breise chun cineálacha bunachar sonraí eile a roghnú.",
    "For more details check out the documentation." : "Le haghaidh tuilleadh sonraí féach ar an doiciméadú.",
    "Performance warning" : "Rabhadh feidhmíochta",
    "You chose SQLite as database." : "Roghnaigh tú SQLite mar bhunachar sonraí.",
    "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "Níor cheart SQLite a úsáid ach amháin le haghaidh cásanna íosta agus forbartha. Le haghaidh táirgeadh molaimid inneall bunachar sonraí difriúil.",
    "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Má úsáideann tú cliaint chun comhaid a shioncronú, ní miste go mór úsáid SQLite.",
    "Database connection" : "Nasc bunachar sonraí",
    "Database user" : "Úsáideoir bunachar sonraí",
    "Database password" : "Pasfhocal bunachar sonraí",
    "Database name" : "Ainm bunachar sonraí",
    "Database tablespace" : "Bunachar sonraí spás tábla",
    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Sonraigh le do thoil uimhir an phoirt mar aon le hainm an óstaigh (m.sh., localhost: 5432).",
    "Database host" : "Óstach bunachar sonraí",
    "localhost" : "áitiúil-óstach",
    "Installing …" : "Ag suiteáil …",
    "Install" : "Suiteáil",
    "Need help?" : "Teastaionn Cabhair?",
    "See the documentation" : "Féach ar an doiciméadú",
    "{name} version {version} and above" : "{name} leagan {version} agus os a chionn",
    "This browser is not supported" : "Ní thacaítear leis an mbrabhsálaí seo",
    "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Ní thacaítear le do bhrabhsálaí. Uasghrádaigh go leagan níos nuaí nó go leagan a dtacaítear leis le do thoil.",
    "Continue with this unsupported browser" : "Lean ar aghaidh leis an mbrabhsálaí seo nach dtacaítear leis",
    "Supported versions" : "Leaganacha tacaithe",
    "Search {types} …" : "Cuardaigh {types} …",
    "Choose {file}" : "Roghnaigh {file}",
    "Choose" : "Roghnaigh",
    "Copy to {target}" : "Cóipeáil chuig {target}",
    "Copy" : "Cóipeáil",
    "Move to {target}" : "Bog go {target}",
    "Move" : "Bog",
    "OK" : "Ceart go leor",
    "read-only" : "léamh amháin",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} coimhlint comhaid","{count} coimhlintí comhaid","{count} coimhlintí comhaid","{count} coimhlintí comhaid","{count} coimhlintí comhaid"],
    "One file conflict" : "Coimhlint comhad amháin",
    "New Files" : "Comhaid Nua",
    "Already existing files" : "Comhaid atá ann cheana féin",
    "Which files do you want to keep?" : "Cé na comhaid ar mhaith leat a choinneáil?",
    "If you select both versions, the copied file will have a number added to its name." : "Má roghnaíonn tú an dá leagan, cuirfear uimhir lena ainm sa chomhad cóipeáilte.",
    "Cancel" : "Cealaigh",
    "Continue" : "Leanúint ar aghaidh",
    "(all selected)" : "(roghnaithe go léir)",
    "({count} selected)" : "({count} roghnaithe)",
    "Error loading file exists template" : "Earráid agus an comhad á lódáil tá an teimpléad ann",
    "Saving …" : "Shábháil …",
    "Groups" : "Grúpaí",
    "Group list is empty" : "Tá liosta an ghrúpa folamh",
    "Unable to retrieve the group list" : "Ní féidir liosta na ngrúpaí a fháil",
    "seconds ago" : "soicind ó shin",
    "Connection to server lost" : "Ceangal leis an bhfreastalaí caillte",
    "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Fadhb le lódáil an leathanaigh, á athlódáil i %n soicind ","Fadhb le lódáil an leathanaigh, á athlódáil i %n soicind ","Fadhb le lódáil an leathanaigh, á athlódáil i %n soicind ","Fadhb le lódáil an leathanaigh, á athlódáil i %n soicind ","Fadhb le lódáil an leathanaigh, á athlódáil i %n soicind "],
    "Add to a project" : "Cuir le tionscadal",
    "Show details" : "Sonraí a thaispeáint",
    "Hide details" : "Folaigh sonraí",
    "Rename project" : "Athainmnigh an tionscadal",
    "Failed to rename the project" : "Theip ar an tionscadal a athainmniú",
    "Failed to create a project" : "Theip ar thionscadal a chruthú",
    "Failed to add the item to the project" : "Theip ar an mír a chur leis an tionscadal",
    "Connect items to a project to make them easier to find" : "Ceangail míreanna le tionscadal chun iad a dhéanamh níos éasca iad a aimsiú",
    "Type to search for existing projects" : "Clóscríobh chun tionscadail atá ann cheana a chuardach",
    "New in" : "Nua isteach",
    "View changelog" : "Féach ar loga na n-athruithe",
    "Close \"{dialogTitle}\" dialog" : "Dún dialóg \"{dialogTitle}\".",
    "Email length is at max (255)" : "Tá fad an ríomhphoist ag uasmhéid (255)",
    "Clipboard not available, please copy manually" : "Níl an gearrthaisce ar fáil, cóipeáil de láimh",
    "Personal" : "Pearsanta",
    "Accounts" : "Cuntais",
    "Admin" : "Riarachán",
    "Help" : "Cabhrú",
    "Access forbidden" : "Rochtain toirmiscthe",
    "You are not allowed to access this page." : "Níl cead agat rochtain a fháil ar an leathanach seo.",
    "Back to %s" : "Ar ais go dtí %s",
    "Page not found" : "Ní bhfuarthas an leathanach",
    "The page could not be found on the server or you may not be allowed to view it." : "Níorbh fhéidir an leathanach a fháil ar an bhfreastalaí nó b'fhéidir nach bhfuil cead agat é a fheiceáil.",
    "Too many requests" : "An iomarca iarratas",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Tháinig an iomarca iarratas ó do líonra. Bain triail eile as ar ball nó déan teagmháil le do riarthóir más earráid é seo.",
    "Error" : "Earráid",
    "Internal Server Error" : "Earráid Freastalaí Inmheánach",
    "The server was unable to complete your request." : "Níorbh fhéidir leis an bhfreastalaí d'iarratas a chomhlánú.",
    "If this happens again, please send the technical details below to the server administrator." : "Má tharlaíonn sé seo arís, seol na sonraí teicniúla thíos chuig riarthóir an fhreastalaí le do thoil.",
    "More details can be found in the server log." : "Is féidir tuilleadh sonraí a fháil i loga an fhreastalaí.",
    "For more details see the documentation ↗." : "Le haghaidh tuilleadh sonraí féach an doiciméadú ↗.",
    "Technical details" : "Sonraí teicniúla",
    "Remote Address: %s" : "Seoladh cianda: %s",
    "Request ID: %s" : "Iarratas aitheantais:%s",
    "Type: %s" : "Cineál: %s",
    "Code: %s" : "Cód: %s",
    "Message: %s" : "Teachtaireacht: %s",
    "File: %s" : "Comhad: %s",
    "Line: %s" : "Líne: %s",
    "Trace" : "Rian",
    "It looks like you are trying to reinstall your Nextcloud. However the file CAN_INSTALL is missing from your config directory. Please create the file CAN_INSTALL in your config folder to continue." : "Tá an chuma ar an scéal go bhfuil tú ag iarraidh do Nextcloud a athshuiteáil. Tá an comhad CAN_INSTALL in easnamh ar do chomhadlann cumraíochta áfach. Cruthaigh an comhad CAN_INSTALL i d'fhillteán cumraíochta chun leanúint ar aghaidh le do thoil.",
    "Could not remove CAN_INSTALL from the config folder. Please remove this file manually." : "Níorbh fhéidir CAN_INSTALL a bhaint den fhillteán cumraíochta. Bain an comhad seo de láimh le do thoil.",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Teastaíonn JavaScript ón bhfeidhmchlár seo chun oibriú ceart. Le do thoil {linkstart}Cumasaigh JavaScript{linkend} agus athlódáil an leathanach le do thoil.",
    "Skip to main content" : "Téigh ar aghaidh chuig an bpríomhábhar",
    "Skip to navigation of app" : "Téigh ar aghaidh chuig nascleanúint an aip",
    "Go to %s" : "Téigh go %s",
    "Get your own free account" : "Faigh do chuntas saor in aisce féin",
    "Previous" : "Roimhe Seo",
    "Two-factor authentication" : "Fíordheimhniú dhá-fhachtóir",
    "Enhanced security is enabled for your account. Choose a second factor for authentication:" : "Tá slándáil fheabhsaithe cumasaithe do do chuntas. Roghnaigh an dara fachtóir le haghaidh fíordheimhnithe:",
    "Could not load at least one of your enabled two-factor auth methods. Please contact your admin." : "Níorbh fhéidir ceann amháin ar a laghad de do mhodhanna údaraithe dhá-fhachtóir a lódáil. Déan teagmháil le do riarthóir le do thoil.",
    "Two-factor authentication is enforced but has not been configured on your account. Contact your admin for assistance." : "Cuirtear fíordheimhniú dhá-fhachtóir i bhfeidhm ach níl sé cumraithe ar do chuntas. Déan teagmháil le do riarthóir chun cabhair a fháil.",
    "Two-factor authentication is enforced but has not been configured on your account. Please continue to setup two-factor authentication." : "Cuirtear fíordheimhniú dhá-fhachtóir i bhfeidhm ach níl sé cumraithe ar do chuntas. Lean ort le fíordheimhniú dhá fhachtóir a shocrú le do thoil.",
    "Set up two-factor authentication" : "Socraigh fíordheimhniú dhá-fhachtóir",
    "Two-factor authentication is enforced but has not been configured on your account. Use one of your backup codes to log in or contact your admin for assistance." : "Cuirtear fíordheimhniú dhá-fhachtóir i bhfeidhm ach níl sé cumraithe ar do chuntas. Bain úsáid as ceann de do chóid chúltaca chun logáil isteach nó déan teagmháil le do riarthóir chun cúnamh a fháil.",
    "Use backup code" : "Úsáid cód cúltaca",
    "Cancel login" : "Cealaigh logáil isteach",
    "Enhanced security is enforced for your account. Choose which provider to set up:" : "Cuirtear slándáil fheabhsaithe i bhfeidhm ar do chuntas. Roghnaigh cén soláthraí atá le socrú:",
    "Error while validating your second factor" : "Earráid agus do dhara fachtóir á bhailíochtú",
    "Access through untrusted domain" : "Rochtain trí fhearann neamhiontaofa",
    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Déan teagmháil le do riarthóir le do thoil. Más riarthóir thú, cuir an socrú \"trusted_domains\" in eagar i config/config.php cosúil leis an sampla i config.sample.php.",
    "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Tá tuilleadh eolais ar conas é seo a chumrú le fáil sa cháipéisíocht %1$s%2$s.",
    "App update required" : "Nuashonrú aip ag teastáil",
    "%1$s will be updated to version %2$s" : "%1$s a nuashonrú go leagan %2$s",
    "The following apps will be updated:" : "Déanfar na haipeanna seo a leanas a nuashonrú:",
    "These incompatible apps will be disabled:" : "Díchumasófar na haipeanna neamh-chomhoiriúnacha seo:",
    "The theme %s has been disabled." : "Díchumasaíodh an téama %s.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Cinntigh, le do thoil, go bhfuil an bunachar sonraí, an fillteán cumraíochta agus an fillteán sonraí cúltacaithe sula dtéann tú ar aghaidh.",
    "Start update" : "Tosaigh nuashonrú",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Chun sosanna ama a sheachaint le suiteálacha níos mó, is féidir leat an t-ordú seo a leanas a rith ó do eolaire suiteála:",
    "Detailed logs" : "Logchomhaid mhionsonraithe",
    "Update needed" : "Nuashonrú ag teastáil",
    "Please use the command line updater because you have a big instance with more than 50 accounts." : "Bain úsáid as an nuashonrú líne ordaithe toisc go bhfuil ásc mór agat le níos mó ná 50 cuntas le do thoil.",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Chun cabhair a fháil, féach an  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>.",
    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Tá a fhios agam má leanann mé ar aghaidh ag déanamh an nuashonraithe trí Chomhéadain Gréasáin go bhfuil an baol ann go n-imeoidh an t-iarratas isteach in am istigh agus go bhféadfadh sé a bheith ina chúis le caillteanas sonraí, ach tá cúltaca agam agus tá a fhios agam conas mo chás a chur ar ais i gcás teipe.",
    "Upgrade via web on my own risk" : "Uasghrádú tríd an ngréasán ar mo phriacal féin",
    "Maintenance mode" : "Modh cothabhála",
    "This %s instance is currently in maintenance mode, which may take a while." : "Tá an cás %s seo i mód cothabhála faoi láthair, agus seans go dtógfaidh sé sin tamall.",
    "This page will refresh itself when the instance is available again." : "Athnóidh an leathanach seo é féin nuair a bheidh an t-ásc ar fáil arís.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Déan teagmháil le riarthóir do chórais má leanann an teachtaireacht seo nó má thaispeánfar gan choinne.",
    "Error occurred while checking server setup" : "Tharla earráid agus socrú an fhreastalaí á sheiceáil",
    "For more details see the {linkstart}documentation ↗{linkend}." : "Le haghaidh tuilleadh sonraí féach an {linkstart}doiciméadú ↗{linkend}.",
    "unknown text" : "téacs anaithnid",
    "Hello world!" : "Dia duit, a dhomhan!",
    "sunny" : "Grianmhar",
    "Hello {name}, the weather is {weather}" : "Dia duit {name}, tá an aimsir {weather}",
    "Hello {name}" : "Dia duit {name}",
    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Seo iad do thorthaí cuardaigh<script>foláireamh(1)</script></strong>",
    "new" : "nua",
    "_download %n file_::_download %n files_" : ["íoslódáil %n comhad","íoslódáil %n comhaid","íoslódáil %n comhaid","íoslódáil %n comhaid","íoslódáil %n comhaid"],
    "Direct link copied to clipboard" : "Cóipeáladh nasc díreach chuig an ngearrthaisce",
    "Searching …" : "Ag cuardach…",
    "Logging in …" : "Ag logáil isteach…",
    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Bhraitheamar go leor iarrachtaí logáil isteach neamhbhailí ó do IP. Dá bhrí sin tá do logáil isteach eile throttled suas go dtí 30 soicind.",
    "Loading apps …" : "Aipeanna á lódáil…",
    "Installing apps …" : "Aipeanna á suiteáil…",
    "Loading your contacts …" : "Do theagmhálaithe á lódáil…",
    "Looking for {term} …" : "Ag lorg {term} …",
    "Search contacts …" : "Cuardaigh teagmhálaithe…",
    "Loading more results …" : "Tuilleadh torthaí á lódáil…",
    "Search {types} …" : "Cuardaigh {types} …",
    "Saving …" : "Shábháil …",
    "Very weak password" : "Pasfhocal an-lag",
    "Weak password" : "Pasfhocal lag",
    "So-so password" : "mar sin-sin pasfhocal",
    "Good password" : "pasfhocal maith",
    "Strong password" : "Pasfhocal láidir",
    "No action available" : "Níl aon ghníomh ar fáil",
    "Error fetching contact actions" : "Earráid agus gníomhartha teagmhála á bhfáil",
    "Non-existing tag #{tag}" : "Clib nach bhfuil ann #{tag}",
    "Restricted" : "Srianta",
    "Delete" : "Scrios",
    "Rename" : "Athainmnigh",
    "Collaborative tags" : "Clibeanna comhoibríocha",
    "No tags found" : "Níor aimsíodh clibeanna",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Is dócha go bhfuil do eolaire sonraí agus comhaid inrochtana ón idirlíon toisc nach n-oibríonn an comhad .htaccess.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Chun tuilleadh faisnéise a fháil faoi conas do fhreastalaí a chumrú i gceart, féach ar an <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">doiciméad</a>le do thoil. ",
    "<strong>Create an admin account</strong>" : "<strong>Cruthaigh cuntas riaracháin</strong>",
    "New admin account name" : "Ainm cuntais riaracháin nua",
    "New admin password" : "Pasfhocal riarthóir nua",
    "Show password" : "Taispeáin pasfhocal",
    "Toggle password visibility" : "Scoránaigh infheictheacht pasfhocail",
    "Configure the database" : "Cumraigh an bunachar sonraí",
    "Only %s is available." : "Níl ach %s ar fáil.",
    "Database account" : "Cuntas bunachar sonraí",
    "Installing …" : "Suiteáil…",
    "Please log in before granting %1$s access to your %2$s account." : "Logáil isteach sula dtabharfaidh tú rochtain do %1$s ar do chuntas %2$s.",
    "Currently logged in as %1$s (%2$s)." : "Logáilte isteach mar %1$s (%2$s) faoi láthair.",
    "You are about to grant %1$s access to your %2$s account." : "Tá tú ar tí rochtain a thabhairt do %1$s ar do chuntas %2$s."
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
